Data
====

Trained Models
--------------
- `Bepler & Berger language model <http://cb.csail.mit.edu/cb/dscript/data/models/lm_v1.sav>`_
- `Human Topsy-Turvy model <http://cb.csail.mit.edu/cb/dscript/data/models/topsy_turvy_v1.sav>`_ **(recommended)**
- `Human D-SCRIPT model  <http://cb.csail.mit.edu/cb/dscript/data/models/human_v1.sav>`_ (from original D-SCRIPT paper)

Sample Data
-----------

Sequences
~~~~~~~~~
- `Human`_
- `Mouse`_
- `Fly`_
- `Yeast`_
- `Worm`_
- `E.coli`_

Interactions
~~~~~~~~~~~~
- `Human Train`_
- `Human Test`_
- `Mouse Test`_
- `Fly Test`_
- `Yeast Test`_
- `Worm Test`_
- `E. coli Test`_

.. _`Human`: https://github.com/samsledje/D-SCRIPT/blob/main/data/seqs/human.fasta
.. _`Mouse`: https://github.com/samsledje/D-SCRIPT/blob/main/data/seqs/mouse.fasta
.. _`Fly`: https://github.com/samsledje/D-SCRIPT/blob/main/data/seqs/fly.fasta
.. _`Yeast`: https://github.com/samsledje/D-SCRIPT/blob/main/data/seqs/yeast.fasta
.. _`Worm`: https://github.com/samsledje/D-SCRIPT/blob/main/data/seqs/worm.fasta
.. _`E.coli`: https://github.com/samsledje/D-SCRIPT/blob/main/data/seqs/ecoli.fasta
.. _`Human Train`: https://github.com/samsledje/D-SCRIPT/blob/main/data/pairs/human_train.tsv
.. _`Human Test`: https://github.com/samsledje/D-SCRIPT/blob/main/data/pairs/human_test.tsv
.. _`Mouse Test`: https://github.com/samsledje/D-SCRIPT/blob/main/data/pairs/mouse_test.tsv
.. _`Fly Test`: https://github.com/samsledje/D-SCRIPT/blob/main/data/pairs/fly_test.tsv
.. _`Yeast Test`: https://github.com/samsledje/D-SCRIPT/blob/main/data/pairs/yeast_test.tsv
.. _`Worm Test`: https://github.com/samsledje/D-SCRIPT/blob/main/data/pairs/worm_test.tsv
.. _`E. coli Test`: https://github.com/samsledje/D-SCRIPT/blob/main/data/pairs/ecoli_test.tsv
